            #GIT_CMT=8f97bad61f7ebb476b36221fe63e0126cdbe9972
# -*- rpm-spec -*-

# This spec file assumes you are building on a Fedora or RHEL version
# that's still supported by the vendor. It may work on other distros
# or versions, but no effort will be made to ensure that going forward.
%define min_rhel 7
%define min_fedora 29

%if (0%{?fedora} && 0%{?fedora} >= %{min_fedora}) || (0%{?rhel} && 0%{?rhel} >= %{min_rhel})
    %define supported_platform 1
%else
    %define supported_platform 0
%endif

# Default to skipping autoreconf.  Distros can change just this one line
# (or provide a command-line override) if they backport any patches that
# touch configure.ac or Makefile.am.
%{!?enable_autotools:%global enable_autotools 0}

# The hypervisor drivers that run in libvirtd
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:1}

%define with_qemu_tcg      %{with_qemu}

%define qemu_kvm_arches %{ix86} x86_64

%if 0%{?fedora}
    %define qemu_kvm_arches %{ix86} x86_64 %{power64} s390x %{arm} aarch64
%endif

%if 0%{?rhel}
    %define with_qemu_tcg 0
    %define qemu_kvm_arches x86_64 %{power64} aarch64 s390x
%endif

%ifarch %{qemu_kvm_arches}
    %define with_qemu_kvm      %{with_qemu}
%else
    %define with_qemu_kvm      0
%endif

%if ! %{with_qemu_tcg} && ! %{with_qemu_kvm}
    %define with_qemu 0
%endif

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_phyp          0%{!?_without_phyp:1}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:1}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd      0%{!?_without_storage_rbd:1}
%if 0%{?fedora}
    %define with_storage_sheepdog 0%{!?_without_storage_sheepdog:1}
%else
    %define with_storage_sheepdog 0
%endif
%define with_storage_gluster 0%{!?_without_storage_gluster:1}
%define with_numactl          0%{!?_without_numactl:1}

# F25+ has zfs-fuse
%if 0%{?fedora}
    %define with_storage_zfs      0%{!?_without_storage_zfs:1}
%else
    %define with_storage_zfs      0
%endif

# We need a recent enough libiscsi (>= 1.18.0)
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:1}
%else
    %define with_storage_iscsi_direct 0
%endif

# A few optional bits off by default, we enable later
%define with_fuse          0%{!?_without_fuse:0}
%define with_sanlock       0%{!?_without_sanlock:0}
%define with_numad         0%{!?_without_numad:0}
%define with_firewalld     0%{!?_without_firewalld:0}
%define with_firewalld_zone 0%{!?_without_firewalld_zone:0}
%define with_libssh2       0%{!?_without_libssh2:0}
%define with_wireshark     0%{!?_without_wireshark:0}
%define with_libssh        0%{!?_without_libssh:0}
%define with_bash_completion  0%{!?_without_bash_completion:0}

# Finally set the OS / architecture specific special cases

# Xen is available only on i386 x86_64 ia64
%ifnarch %{ix86} x86_64 ia64
    %define with_libxl 0
%endif

# vbox is available only on i386 x86_64
%ifnarch %{ix86} x86_64
    %define with_vbox 0
%endif

# Numactl is not available on many non-x86 archs
%ifarch s390 s390x %{arm} riscv64
    %define with_numactl 0
%endif

# zfs-fuse is not available on some architectures
%ifarch s390 s390x aarch64 riscv64
    %define with_storage_zfs 0
%endif

# Ceph dropping support for 32-bit hosts
%if 0%{?fedora} >= 30
    %ifarch %{arm} %{ix86}
        %define with_storage_rbd 0
    %endif
%endif

# RHEL doesn't ship OpenVZ, VBox, PowerHypervisor,
# VMware, libxenserver (xenapi), libxenlight (Xen 4.1 and newer),
# or HyperV.
%if 0%{?rhel}
    %define with_openvz 0
    %define with_vbox 0
    %define with_phyp 0
    %define with_vmware 0
    %define with_xenapi 0
    %define with_libxl 0
    %define with_hyperv 0
    %define with_vz 0

    %if 0%{?rhel} > 7
        %define with_lxc 0
    %endif
%endif

# OL
%if 0%{?rhel} >= 7
    %define with_parallels 0
    %define with_esx 1
    %define with_vmware 1
    %define with_qemu 1
    %define with_xen 0
    %define with_libxl 0
    %define with_qemu_kvm 1
    %if 0%{?rhel} == 7
        %define with_qemu_tcg 1
    %endif
    %define with_lxc 1
    %define with_storage_gluster 1
    %define with_storage_rbd 1
    %define with_sanlock 1
%endif

%define with_firewalld 1

%if 0%{?fedora} >= 31 || 0%{?rhel} > 7
    %define with_firewalld_zone 0%{!?_without_firewalld_zone:1}
%endif


# fuse is used to provide virtualized /proc for LXC
%if %{with_lxc}
    %define with_fuse      0%{!?_without_fuse:1}
%endif

# Enable sanlock library for lock management with QEMU
# Sanlock is available only on arches where kvm is available for RHEL
%if 0%{?fedora}
    %define with_sanlock 0%{!?_without_sanlock:1}
%endif
%if 0%{?rhel}
    %ifarch %{qemu_kvm_arches}
        %define with_sanlock 0%{!?_without_sanlock:1}
    %endif
%endif

# Enable libssh2 transport for new enough distros
%if 0%{?fedora}
    %define with_libssh2 0%{!?_without_libssh2:1}
%endif

# Enable wireshark plugins for all distros shipping libvirt 1.2.2 or newer
%if 0%{?fedora}
    %define with_wireshark 0%{!?_without_wireshark:1}
    %define wireshark_plugindir %(pkg-config --variable plugindir wireshark)/epan
%endif

# Enable libssh transport for new enough distros
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_libssh 0%{!?_without_libssh:1}
%endif

%define with_bash_completion  0%{!?_without_bash_completion:1}

# Use Python 3 when possible, Python 2 otherwise
%if 0%{?fedora} || 0%{?rhel} > 7
    %define python python3
%else
    %define python python2
%endif


%if %{with_qemu} || %{with_lxc}
# numad is used to manage the CPU and memory placement dynamically,
# it's not available on many non-x86 architectures.
    %ifnarch s390 s390x %{arm} riscv64
        %define with_numad    0%{!?_without_numad:1}
    %endif
%endif

# Force QEMU to run as non-root
%define qemu_user  qemu
%define qemu_group  qemu


# RHEL releases provide stable tool chains and so it is safe to turn
# compiler warning into errors without being worried about frequent
# changes in reported warnings
%if 0%{?rhel}
    %define enable_werror --enable-werror
%else
    %define enable_werror --disable-werror
%endif

%if 0%{?rhel} == 7
    %define tls_priority "NORMAL"
%else
    %define tls_priority "@LIBVIRT,SYSTEM"
%endif

%{!?buildid: %{expand: %%define buildid 1}}

Summary: Library providing a simple virtualization API
Name: libvirt
Version: 5.7.0
Release:    40.el7
License: LGPLv2+
URL: https://libvirt.org/

%if %(echo %{version} | grep -q "\.0$"; echo $?) == 1
    %define mainturl stable_updates/
%endif
Source: libvirt-5.7.0.tar.bz2

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-config-network = %{version}-%{release}
Requires: libvirt-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_lxc}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
%endif
%if %{with_qemu}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
%endif
# We had UML driver, but we've removed it.
Obsoletes: libvirt-daemon-driver-uml <= 5.0.0
Obsoletes: libvirt-daemon-uml <= 5.0.0
%if %{with_vbox}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-client = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
BuildRequires: libtool
BuildRequires: /usr/bin/pod2man
%endif
BuildRequires: gcc
BuildRequires: git
%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: perl-interpreter
%else
BuildRequires: perl
%endif
BuildRequires: %{python}
BuildRequires: systemd-units
%if %{with_libxl}
BuildRequires: xen-devel
%endif
BuildRequires: libxml2-devel
BuildRequires: libxslt
BuildRequires: readline-devel
%if %{with_bash_completion}
BuildRequires: bash-completion >= 2.0
%endif
BuildRequires: ncurses-devel
BuildRequires: gettext
BuildRequires: libtasn1-devel
BuildRequires: gnutls-devel
BuildRequires: libattr-devel
# For pool-build probing for existing pools
BuildRequires: libblkid-devel >= 2.17
# for augparse, optionally used in testing
BuildRequires: augeas
BuildRequires: systemd-devel >= 185
BuildRequires: libpciaccess-devel >= 0.10.9
BuildRequires: yajl-devel
%if %{with_sanlock}
BuildRequires: sanlock-devel >= 2.4
%endif
BuildRequires: libpcap-devel
BuildRequires: libnl3-devel
BuildRequires: libselinux-devel
BuildRequires: dnsmasq >= 2.41
BuildRequires: iptables
BuildRequires: radvd
BuildRequires: ebtables
BuildRequires: module-init-tools
BuildRequires: cyrus-sasl-devel
BuildRequires: polkit >= 0.112
# For mount/umount in FS driver
BuildRequires: util-linux
%if %{with_qemu}
# For managing ACLs
BuildRequires: libacl-devel
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%endif
# For LVM drivers
BuildRequires: lvm2
# For pool type=iscsi
BuildRequires: iscsi-initiator-utils
%if %{with_storage_iscsi_direct}
# For pool type=iscsi-direct
BuildRequires: libiscsi-devel
%endif
# For disk driver
BuildRequires: parted-devel
# For Multipath support
BuildRequires: device-mapper-devel
# For XFS reflink clone support
BuildRequires: xfsprogs-devel
%if %{with_storage_rbd}
BuildRequires: librados2-devel
BuildRequires: librbd1-devel
%endif
%if %{with_storage_gluster}
BuildRequires: glusterfs-api-devel >= 3.4.1
BuildRequires: glusterfs-devel >= 3.4.1
%endif
%if %{with_storage_sheepdog}
BuildRequires: sheepdog
%endif
%if %{with_storage_zfs}
# Support any conforming implementation of zfs. On stock Fedora
# this is zfs-fuse, but could be zfsonlinux upstream RPMs
BuildRequires: /sbin/zfs
BuildRequires: /sbin/zpool
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-ng-devel >= 0.5.0
%if %{with_fuse}
BuildRequires: fuse-devel >= 2.8.6
%endif
%if %{with_phyp} || %{with_libssh2}
BuildRequires: libssh2-devel >= 1.3.0
%endif

BuildRequires: netcf-devel >= 0.2.2
%if %{with_esx}
BuildRequires: libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires: libwsman-devel >= 2.2.3
%endif
BuildRequires: audit-libs-devel
# we need /usr/sbin/dtrace
BuildRequires: systemtap-sdt-devel

# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils

# Communication with the firewall and polkit daemons use DBus
BuildRequires: dbus-devel

# Fedora build root suckage
BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires: scrub

%if %{with_numad}
BuildRequires: numad
%endif

%if %{with_wireshark}
BuildRequires: wireshark-devel >= 2.4.0
%endif

%if %{with_libssh}
BuildRequires: libssh-devel >= 0.7.0
%endif

%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: rpcgen
BuildRequires: libtirpc-devel
%endif

%if %{with_firewalld_zone}
BuildRequires: firewalld-filesystem
%endif

Provides: bundled(gnulib)

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes). The main package includes
the libvirtd server exporting the virtualization support.

%package docs
Summary: API reference and website documentation

%description docs
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary: Server side daemon and supporting files for libvirt library

# All runtime requirements for the libvirt package (runtime requrements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs are in a subpackage
Requires: %{name}-libs = %{version}-%{release}

# (client invokes 'nc' against the UNIX socket on the server)
%if 0%{?rhel} >= 8
Recommends: /usr/bin/nc
%else
Requires: /usr/bin/nc
%endif

# for modprobe of pci devices
Requires: module-init-tools

# for /sbin/ip & /sbin/tc
Requires: iproute
# tc is provided by iproute-tc since at least Fedora 26
%if 0%{?fedora} || 0%{?rhel} >= 7
Requires: iproute-tc
%endif

Requires: polkit >= 0.112
%ifarch %{ix86} x86_64 ia64
# For virConnectGetSysinfo
Requires: dmidecode
%endif
# For service management
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
%if %{with_numad}
Requires: numad
%endif
# libvirtd depends on 'messagebus' service
Requires: dbus
# For uid creation during pre
Requires(pre): shadow-utils

Obsoletes: libvirt-autonuma-config-hook

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-config-network
Summary: Default configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary: Network filter configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for cleaning guest traffic

%package daemon-driver-network
Summary: Network driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: dnsmasq >= 2.41
Requires: radvd
Requires: iptables

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.


%package daemon-driver-nwfilter
Summary: Nwfilter driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iptables
Requires: ebtables

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities


%package daemon-driver-nodedev
Summary: Nodedev driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# needed for device enumeration
Requires: systemd >= 185

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.


%package daemon-driver-interface
Summary: Interface driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: netcf-libs >= 0.2.2

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcf library


%package daemon-driver-secret
Summary: Secret driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.

%package daemon-driver-storage-core
Summary: Storage driver plugin including base backends for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: nfs-utils
# For mkfs
Requires: util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires: /usr/bin/qemu-img
%endif
%if !%{with_storage_rbd}
Obsoletes: libvirt-daemon-driver-storage-rbd < %{version}-%{release}
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%package daemon-driver-storage-logical
Summary: Storage driver plugin for lvm volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.


%package daemon-driver-storage-disk
Summary: Storage driver plugin for disk
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: parted
Requires: device-mapper

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.


%package daemon-driver-storage-scsi
Summary: Storage driver plugin for local scsi devices
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.


%package daemon-driver-storage-iscsi
Summary: Storage driver plugin for iscsi
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iscsi-initiator-utils

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.


%if %{with_storage_iscsi_direct}
%package daemon-driver-storage-iscsi-direct
Summary: Storage driver plugin for iscsi-direct
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: libiscsi

%description daemon-driver-storage-iscsi-direct
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using libiscsi direct connection.
%endif


%package daemon-driver-storage-mpath
Summary: Storage driver plugin for multipath volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.


%if %{with_storage_gluster}
%package daemon-driver-storage-gluster
Summary: Storage driver plugin for gluster
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
    %if 0%{?fedora}
Requires: glusterfs-client >= 2.0.1
    %endif
    %if (0%{?fedora} || 0%{?with_storage_gluster})
Requires: /usr/sbin/gluster
    %endif

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.
%endif


%if %{with_storage_rbd}
%package daemon-driver-storage-rbd
Summary: Storage driver plugin for rbd
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.
%endif


%if %{with_storage_sheepdog}
%package daemon-driver-storage-sheepdog
Summary: Storage driver plugin for sheepdog
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: sheepdog

%description daemon-driver-storage-sheepdog
The storage driver backend adding implementation of the storage APIs for
sheepdog volumes using.
%endif


%if %{with_storage_zfs}
%package daemon-driver-storage-zfs
Summary: Storage driver plugin for ZFS
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# Support any conforming implementation of zfs
Requires: /sbin/zfs
Requires: /sbin/zpool

%description daemon-driver-storage-zfs
The storage driver backend adding implementation of the storage APIs for
ZFS volumes.
%endif


%package daemon-driver-storage
Summary: Storage driver plugin including all backends for the libvirtd daemon
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-disk = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-logical = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-scsi = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-iscsi = %{version}-%{release}
Requires: libvirt-daemon-driver-storage-mpath = %{version}-%{release}
%if %{with_storage_iscsi_direct}
Requires: libvirt-daemon-driver-storage-iscsi-direct = %{version}-%{release}
%endif
%if %{with_storage_gluster}
Requires: libvirt-daemon-driver-storage-gluster = %{version}-%{release}
%endif
%if %{with_storage_rbd}
Requires: libvirt-daemon-driver-storage-rbd = %{version}-%{release}
%endif
%if %{with_storage_sheepdog}
Requires: libvirt-daemon-driver-storage-sheepdog = %{version}-%{release}
%endif
%if %{with_storage_zfs}
Requires: libvirt-daemon-driver-storage-zfs = %{version}-%{release}
%endif

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.


%if %{with_qemu}
%package daemon-driver-qemu
Summary: QEMU driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: /usr/bin/qemu-img
# For image compression
Requires: gzip
Requires: bzip2
Requires: lzop
Requires: xz
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
QEMU
%endif


%if %{with_lxc}
%package daemon-driver-lxc
Summary: LXC driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires: libvirt-daemon-driver-network = %{version}-%{release}
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif


%if %{with_vbox}
%package daemon-driver-vbox
Summary: VirtualBox driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif


%if %{with_libxl}
%package daemon-driver-libxl
Summary: Libxl driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Obsoletes: libvirt-daemon-driver-xen < 4.3.0

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Libxl
%endif



%if %{with_qemu_tcg}
%package daemon-qemu
Summary: Server side daemon & driver required to run QEMU guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU TCG emulators
%endif


%if %{with_qemu_kvm}
%package daemon-kvm
Summary: Server side daemon & driver required to run KVM guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu-kvm

%description daemon-kvm
Server side daemon and driver required to manage the virtualization
capabilities of the KVM hypervisor
%endif


%if %{with_lxc}
%package daemon-lxc
Summary: Server side daemon & driver required to run LXC guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif


%if %{with_libxl}
%package daemon-xen
Summary: Server side daemon & driver required to run XEN guests

Requires: libvirt-daemon = %{version}-%{release}
    %if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}
%package daemon-vbox
Summary: Server side daemon & driver required to run VirtualBox guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%package client
Summary: Client side utilities of the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
Requires: ncurses
# Needed by /usr/libexec/libvirt-guests.sh script.
Requires: gettext
# Needed by virt-pki-validate script.
Requires: gnutls-utils
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package libs
Summary: Client side libraries
# So remote clients can access libvirt over SSH tunnel
Requires: cyrus-sasl
# Needed by default sasl.conf - no onerous extra deps, since
# 100's of other things on a system already pull in krb5-libs
Requires: cyrus-sasl-gssapi

%description libs
Shared libraries for accessing the libvirt daemon.

%package admin
Summary: Set of tools to control libvirt daemon
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description admin
The client side utilities to control the libvirt daemon.

%if %{with_bash_completion}
%package bash-completion
Summary: Bash completion script
# Not strictly necessary but provides hint for patch tooling
Requires: %{name}-libs = %{version}-%{release}

%description bash-completion
Bash completion script stub.
%endif

%if %{with_wireshark}
%package wireshark
Summary: Wireshark dissector plugin for libvirt RPC transactions
Requires: wireshark >= 2.4.0
Requires: %{name}-libs = %{version}-%{release}

%description wireshark
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%if %{with_lxc}
%package login-shell
Summary: Login shell for connecting users to an LXC container
Requires: %{name}-libs = %{version}-%{release}

%description login-shell
Provides the set-uid virt-login-shell binary that is used to
connect a user to an LXC container when they login, by switching
namespaces.
%endif

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: pkgconfig

%description devel
Include header files & development libraries for the libvirt C library.

%if %{with_sanlock}
%package lock-sanlock
Summary: Sanlock lock manager plugin for QEMU driver
Requires: sanlock >= 2.4
#for virt-sanlock-cleanup require augeas
Requires: augeas
Requires: %{name}-daemon = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU
driver
%endif

%package nss
Summary: Libvirt plugin for Name Service Switch
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description nss
Libvirt plugin for NSS for translating domain names into IP addresses.


%prep

%autosetup -S git_am

%build
%if ! %{supported_platform}
echo "This RPM requires either Fedora >= %{min_fedora} or RHEL >= %{min_rhel}"
exit 1
%endif

%if %{with_qemu}
    %define arg_qemu --with-qemu
%else
    %define arg_qemu --without-qemu
%endif

%if %{with_openvz}
    %define arg_openvz --with-openvz
%else
    %define arg_openvz --without-openvz
%endif

%if %{with_lxc}
    %define arg_lxc --with-lxc
    %define arg_login_shell --with-login-shell
%else
    %define arg_lxc --without-lxc
    %define arg_login_shell --without-login-shell
%endif

%if %{with_vbox}
    %define arg_vbox --with-vbox
%else
    %define arg_vbox --without-vbox
%endif

%if %{with_libxl}
    %define arg_libxl --with-libxl
%else
    %define arg_libxl --without-libxl
%endif

%if %{with_phyp}
    %define arg_phyp --with-phyp
%else
    %define arg_phyp --without-phyp
%endif

%if %{with_esx}
    %define arg_esx --with-esx
%else
    %define arg_esx --without-esx
%endif

%if %{with_hyperv}
    %define arg_hyperv --with-hyperv
%else
    %define arg_hyperv --without-hyperv
%endif

%if %{with_vmware}
    %define arg_vmware --with-vmware
%else
    %define arg_vmware --without-vmware
%endif

%if %{with_storage_rbd}
    %define arg_storage_rbd --with-storage-rbd
%else
    %define arg_storage_rbd --without-storage-rbd
%endif

%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog --with-storage-sheepdog
%else
    %define arg_storage_sheepdog --without-storage-sheepdog
%endif

%if %{with_storage_gluster}
    %define arg_storage_gluster --with-storage-gluster
%else
    %define arg_storage_gluster --without-storage-gluster
%endif

%if %{with_storage_zfs}
    %define arg_storage_zfs --with-storage-zfs
%else
    %define arg_storage_zfs --without-storage-zfs
%endif

%if %{with_numactl}
    %define arg_numactl --with-numactl
%else
    %define arg_numactl --without-numactl
%endif

%if %{with_numad}
    %define arg_numad --with-numad
%else
    %define arg_numad --without-numad
%endif

%if %{with_fuse}
    %define arg_fuse --with-fuse
%else
    %define arg_fuse --without-fuse
%endif

%if %{with_sanlock}
    %define arg_sanlock --with-sanlock
%else
    %define arg_sanlock --without-sanlock
%endif

%if %{with_firewalld}
    %define arg_firewalld --with-firewalld
%else
    %define arg_firewalld --without-firewalld
%endif

%if %{with_firewalld_zone}
    %define arg_firewalld_zone --with-firewalld-zone
%else
    %define arg_firewalld_zone --without-firewalld-zone
%endif

%if %{with_wireshark}
    %define arg_wireshark --with-wireshark-dissector
%else
    %define arg_wireshark --without-wireshark-dissector
%endif

%if %{with_storage_iscsi_direct}
    %define arg_storage_iscsi_direct --with-storage-iscsi-direct
%else
    %define arg_storage_iscsi_direct --without-storage-iscsi-direct
%endif

%define when  %(date +"%%F-%%T")
%define where %(hostname)
%define who   %{?packager}%{!?packager:Unknown}
%define arg_packager --with-packager="%{who}, %{when}, %{where}"
%define arg_packager_version --with-packager-version="%{release}"

%define arg_selinux_mount --with-selinux-mount="/sys/fs/selinux"

%if 0%{?fedora}
    # Nightly firmware repo x86/OVMF
    LOADERS="/usr/share/edk2.git/ovmf-x64/OVMF_CODE-pure-efi.fd:/usr/share/edk2.git/ovmf-x64/OVMF_VARS-pure-efi.fd"
    # Nightly firmware repo aarch64/AAVMF
    LOADERS="$LOADERS:/usr/share/edk2.git/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2.git/aarch64/vars-template-pflash.raw"
    # Fedora official x86/OVMF
    LOADERS="$LOADERS:/usr/share/edk2/ovmf/OVMF_CODE.fd:/usr/share/edk2/ovmf/OVMF_VARS.fd"
    # Fedora official aarch64/AAVMF
    LOADERS="$LOADERS:/usr/share/edk2/aarch64/QEMU_EFI-pflash.raw:/usr/share/edk2/aarch64/vars-template-pflash.raw"
    %define arg_loader_nvram --with-loader-nvram="$LOADERS"
%endif

# place macros above and build commands below this comment

./bootstrap

%if 0%{?enable_autotools}
 autoreconf -if
%endif

rm -f po/stamp-po
%configure --with-runstatedir=%{_rundir} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           --with-sasl \
           --with-polkit \
           --with-libvirtd \
           %{?arg_phyp} \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           --without-xenapi \
           --without-vz \
           --without-bhyve \
           --with-remote-default-mode=legacy \
           --with-interface \
           --with-network \
           --with-storage-fs \
           --with-storage-lvm \
           --with-storage-iscsi \
           %{?arg_storage_iscsi_direct} \
           --with-storage-scsi \
           --with-storage-disk \
           --with-storage-mpath \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           %{?arg_storage_zfs} \
           --without-storage-vstorage \
           %{?arg_numactl} \
           %{?arg_numad} \
           --with-capng \
           %{?arg_fuse} \
           --with-netcf \
           --with-selinux \
           %{?arg_selinux_mount} \
           --without-apparmor \
           --without-hal \
           --with-udev \
           --with-yajl \
           %{?arg_sanlock} \
           --with-libpcap \
           --with-macvtap \
           --with-audit \
           --with-dtrace \
           --with-driver-modules \
           %{?arg_firewalld} \
           %{?arg_firewalld_zone} \
           %{?arg_wireshark} \
           --without-pm-utils \
           --with-nss-plugin \
           %{arg_packager} \
           %{arg_packager_version} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           --with-tls-priority=%{tls_priority} \
           %{?arg_loader_nvram} \
           %{?enable_werror} \
           --enable-expensive-tests \
           --with-init-script=systemd \
           %{?arg_login_shell}
make %{?_smp_mflags} V=1
gzip -9 ChangeLog

%install
rm -fr %{buildroot}


%make_install %{?_smp_mflags} SYSTEMD_UNIT_DIR=%{_unitdir} V=1

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.a
%if %{with_wireshark}
rm -f $RPM_BUILD_ROOT%{wireshark_plugindir}/libvirt.la
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
# libvirt saves this file with mode 0600
chmod 0600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml

# nwfilter files are installed in /usr/share/libvirt and copied to /etc in %post
# to avoid verification errors on changed files in /etc
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
cp -a $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml \
    $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml

# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_sanlock}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_libxl}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/libxl.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif

# Copied into libvirt-docs subpackage eventually
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt libvirt-docs

%ifarch %{power64} s390x x86_64 ia64 alpha sparc64
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes-64.stp

    %if %{with_qemu}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
    %endif
%endif

%clean
rm -fr %{buildroot}

%check
cd tests
# These tests don't current work in a mock build root
for i in nodeinfotest seclabeltest
do
  rm -f $i
  printf 'int main(void) { return 0; }' > $i.c
  printf '#!/bin/sh\nexit 0\n' > $i
  chmod +x $i
done
if ! make %{?_smp_mflags} check VIR_TEST_DEBUG=1
then
  cat test-suite.log || true
  exit 1
fi

%post libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%postun libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%pre daemon
# 'libvirt' group is just to allow password-less polkit access to
# libvirtd. The uid number is irrelevant, so we use dynamic allocation
# described at the above link.
getent group libvirt >/dev/null || groupadd -r libvirt

exit 0

%post daemon

%systemd_post virtlockd.socket virtlockd-admin.socket
%systemd_post virtlogd.socket virtlogd-admin.socket
%systemd_post libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_post libvirtd-tcp.socket libvirtd-tls.socket
%systemd_post libvirtd.service

# request daemon restart in posttrans
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%preun daemon
%systemd_preun libvirtd.service
%systemd_preun libvirtd-tcp.socket libvirtd-tls.socket
%systemd_preun libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_preun virtlogd.socket virtlogd-admin.socket virtlogd.service
%systemd_preun virtlockd.socket virtlockd-admin.socket virtlockd.service

%postun daemon
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    /bin/systemctl reload-or-try-restart virtlockd.service >/dev/null 2>&1 || :
    /bin/systemctl reload-or-try-restart virtlogd.service >/dev/null 2>&1 || :
fi

# In upgrade scenario we must explicitly enable virtlockd/virtlogd
# sockets, if libvirtd is already enabled and start them if
# libvirtd is running, otherwise you'll get failures to start
# guests
%triggerpostun daemon -- libvirt-daemon < 1.3.0
if [ $1 -ge 1 ] ; then
    /bin/systemctl is-enabled libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl enable virtlogd.socket virtlogd-admin.socket || :
    /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl start virtlogd.socket virtlogd-admin.socket || :
fi

%posttrans daemon
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    # Keep the old style libvirtd behavior as the default. If
    # desired, systemd socket mode activation can be enabled using
    #
    # # systemctl unmask libvirtd.socket libvirtd-ro.socket \
    #                    libvirtd-admin.socket libvirtd-tcp.socket \
    #                    libvirtd-tls.socket
    /bin/systemctl mask libvirtd.socket >/dev/null 2>&1 || :
    /bin/systemctl mask libvirtd-ro.socket >/dev/null 2>&1 || :
    /bin/systemctl mask libvirtd-admin.socket >/dev/null 2>&1 || :
    /bin/systemctl mask libvirtd-tls.socket >/dev/null 2>&1 || :
    /bin/systemctl mask libvirtd-tcp.socket >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%postun daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%post daemon-config-network
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    # see if the network used by default network creates a conflict,
    # and try to resolve it
    # NB: 192.168.122.0/24 is used in the default.xml template file;
    # do not modify any of those values here without also modifying
    # them in the template.
    orig_sub=122
    sub=${orig_sub}
    nl='
'
    routes="${nl}$(ip route show | cut -d' ' -f1)${nl}"
    case ${routes} in
      *"${nl}192.168.${orig_sub}.0/24${nl}"*)
        # there was a match, so we need to look for an unused subnet
        for new_sub in $(seq 124 254); do
          case ${routes} in
          *"${nl}192.168.${new_sub}.0/24${nl}"*)
            ;;
          *)
            sub=$new_sub
            break;
            ;;
          esac
        done
        ;;
      *)
        ;;
    esac

    UUID=`/usr/bin/uuidgen`
    sed -e "s/${orig_sub}/${sub}/g" \
        -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
    # libvirt saves this file with mode 0600
    chmod 0600 %{_sysconfdir}/libvirt/qemu/networks/default.xml

    # Make sure libvirt picks up the new network defininiton
    mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
    touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-network
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-config-nwfilter
cp %{_datadir}/libvirt/nwfilter/*.xml %{_sysconfdir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 %{_sysconfdir}/libvirt/nwfilter/*.xml
# Make sure libvirt picks up the new nwfilter defininitons
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%posttrans daemon-config-nwfilter
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :


%if %{with_qemu}
%pre daemon-driver-qemu
# We want soft static allocation of well-known ids, as disk images
# are commonly shared across NFS mounts by id rather than name; see
# https://fedoraproject.org/wiki/Packaging:UsersAndGroups
getent group kvm >/dev/null || groupadd -f -g 36 -r kvm
getent group qemu >/dev/null || groupadd -f -g 107 -r qemu
if ! getent passwd qemu >/dev/null; then
  if ! getent passwd 107 >/dev/null; then
    useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  else
    useradd -r -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  fi
fi
exit 0
%endif

%preun client

%systemd_preun libvirt-guests.service

%post client
%systemd_post libvirt-guests.service

%postun client
%systemd_postun libvirt-guests.service

%if %{with_lxc}
%pre login-shell
getent group virtlogin >/dev/null || groupadd -r virtlogin
exit 0
%endif

%files

%files docs
%doc AUTHORS ChangeLog.gz README README.md
%doc libvirt-docs/*

# API docs
%dir %{_datadir}/gtk-doc/html/libvirt/
%doc %{_datadir}/gtk-doc/html/libvirt/*.devhelp
%doc %{_datadir}/gtk-doc/html/libvirt/*.html
%doc %{_datadir}/gtk-doc/html/libvirt/*.png
%doc %{_datadir}/gtk-doc/html/libvirt/*.css


%files daemon

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%{_unitdir}/virtproxyd.service
%{_unitdir}/virtproxyd.socket
%{_unitdir}/virtproxyd-ro.socket
%{_unitdir}/virtproxyd-admin.socket
%{_unitdir}/virtproxyd-tcp.socket
%{_unitdir}/virtproxyd-tls.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlogd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtproxyd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_prefix}/lib/sysctl.d/60-libvirtd.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%dir %{_datadir}/libvirt/

%ghost %dir %{_rundir}/libvirt/

%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/


%dir %attr(0755, root, root) %{_libdir}/libvirt/
%dir %attr(0755, root, root) %{_libdir}/libvirt/connection-driver/
%dir %attr(0755, root, root) %{_libdir}/libvirt/lock-driver
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/lockd.so

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/virtproxyd.aug
%{_datadir}/augeas/lenses/tests/test_virtproxyd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%if %{with_qemu}
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%endif

%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper

%attr(0755, root, root) %{_sbindir}/libvirtd
%attr(0755, root, root) %{_sbindir}/virtproxyd
%attr(0755, root, root) %{_sbindir}/virtlogd
%attr(0755, root, root) %{_sbindir}/virtlockd

%{_mandir}/man8/libvirtd.8*
%{_mandir}/man8/virtlogd.8*
%{_mandir}/man8/virtlockd.8*
%{_mandir}/man7/virkey*.7*

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml

%files daemon-config-nwfilter
%dir %{_datadir}/libvirt/nwfilter/
%{_datadir}/libvirt/nwfilter/*.xml
%ghost %{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%config(noreplace) %{_sysconfdir}/libvirt/virtinterfaced.conf
%{_datadir}/augeas/lenses/virtinterfaced.aug
%{_datadir}/augeas/lenses/tests/test_virtinterfaced.aug
%{_unitdir}/virtinterfaced.service
%{_unitdir}/virtinterfaced.socket
%{_unitdir}/virtinterfaced-ro.socket
%{_unitdir}/virtinterfaced-admin.socket
%attr(0755, root, root) %{_sbindir}/virtinterfaced
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so

%files daemon-driver-network
%config(noreplace) %{_sysconfdir}/libvirt/virtnetworkd.conf
%{_datadir}/augeas/lenses/virtnetworkd.aug
%{_datadir}/augeas/lenses/tests/test_virtnetworkd.aug
%{_unitdir}/virtnetworkd.service
%{_unitdir}/virtnetworkd.socket
%{_unitdir}/virtnetworkd-ro.socket
%{_unitdir}/virtnetworkd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnetworkd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%ghost %dir %{_rundir}/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libexecdir}/libvirt_leaseshelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so

%if %{with_firewalld_zone}
%{_prefix}/lib/firewalld/zones/libvirt.xml
%endif

%files daemon-driver-nodedev
%config(noreplace) %{_sysconfdir}/libvirt/virtnodedevd.conf
%{_datadir}/augeas/lenses/virtnodedevd.aug
%{_datadir}/augeas/lenses/tests/test_virtnodedevd.aug
%{_unitdir}/virtnodedevd.service
%{_unitdir}/virtnodedevd.socket
%{_unitdir}/virtnodedevd-ro.socket
%{_unitdir}/virtnodedevd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnodedevd
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so

%files daemon-driver-nwfilter
%config(noreplace) %{_sysconfdir}/libvirt/virtnwfilterd.conf
%{_datadir}/augeas/lenses/virtnwfilterd.aug
%{_datadir}/augeas/lenses/tests/test_virtnwfilterd.aug
%{_unitdir}/virtnwfilterd.service
%{_unitdir}/virtnwfilterd.socket
%{_unitdir}/virtnwfilterd-ro.socket
%{_unitdir}/virtnwfilterd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnwfilterd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%ghost %dir %{_rundir}/libvirt/network/
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so

%files daemon-driver-secret
%config(noreplace) %{_sysconfdir}/libvirt/virtsecretd.conf
%{_datadir}/augeas/lenses/virtsecretd.aug
%{_datadir}/augeas/lenses/tests/test_virtsecretd.aug
%{_unitdir}/virtsecretd.service
%{_unitdir}/virtsecretd.socket
%{_unitdir}/virtsecretd-ro.socket
%{_unitdir}/virtsecretd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtsecretd
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so

%files daemon-driver-storage

%files daemon-driver-storage-core
%config(noreplace) %{_sysconfdir}/libvirt/virtstoraged.conf
%{_datadir}/augeas/lenses/virtstoraged.aug
%{_datadir}/augeas/lenses/tests/test_virtstoraged.aug
%{_unitdir}/virtstoraged.service
%{_unitdir}/virtstoraged.socket
%{_unitdir}/virtstoraged-ro.socket
%{_unitdir}/virtstoraged-admin.socket
%attr(0755, root, root) %{_sbindir}/virtstoraged
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_fs.so

%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%if %{with_storage_iscsi_direct}
%files daemon-driver-storage-iscsi-direct
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi-direct.so
%endif

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_sheepdog}
%files daemon-driver-storage-sheepdog
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_sheepdog.so
%endif

%if %{with_storage_zfs}
%files daemon-driver-storage-zfs
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_zfs.so
%endif

%if %{with_qemu}
%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/libvirt/virtqemud.conf
%{_datadir}/augeas/lenses/virtqemud.aug
%{_datadir}/augeas/lenses/tests/test_virtqemud.aug
%{_unitdir}/virtqemud.service
%{_unitdir}/virtqemud.socket
%{_unitdir}/virtqemud-ro.socket
%{_unitdir}/virtqemud-admin.socket
%attr(0755, root, root) %{_sbindir}/virtqemud
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%ghost %dir %{_rundir}/libvirt/qemu/
%dir %attr(0751, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/cache/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/swtpm/
%dir %attr(0711, root, root) %{_localstatedir}/log/swtpm/libvirt/qemu/
%endif

%if %{with_lxc}
%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/libvirt/virtlxcd.conf
%{_datadir}/augeas/lenses/virtlxcd.aug
%{_datadir}/augeas/lenses/tests/test_virtlxcd.aug
%{_unitdir}/virtlxcd.service
%{_unitdir}/virtlxcd.socket
%{_unitdir}/virtlxcd-ro.socket
%{_unitdir}/virtlxcd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtlxcd
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%ghost %dir %{_rundir}/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%endif

%if %{with_libxl}
%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/libvirt/virtxend.conf
%{_datadir}/augeas/lenses/virtxend.aug
%{_datadir}/augeas/lenses/tests/test_virtxend.aug
%{_unitdir}/virtxend.service
%{_unitdir}/virtxend.socket
%{_unitdir}/virtxend-ro.socket
%{_unitdir}/virtxend-admin.socket
%attr(0755, root, root) %{_sbindir}/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%ghost %dir %{_rundir}/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%endif

%if %{with_vbox}
%files daemon-driver-vbox
%config(noreplace) %{_sysconfdir}/libvirt/virtvboxd.conf
%{_datadir}/augeas/lenses/virtvboxd.aug
%{_datadir}/augeas/lenses/tests/test_virtvboxd.aug
%{_unitdir}/virtvboxd.service
%{_unitdir}/virtvboxd.socket
%{_unitdir}/virtvboxd-ro.socket
%{_unitdir}/virtvboxd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvboxd
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%endif

%if %{with_qemu_tcg}
%files daemon-qemu
%endif

%if %{with_qemu_kvm}
%files daemon-kvm
%endif

%if %{with_lxc}
%files daemon-lxc
%endif

%if %{with_libxl}
%files daemon-xen
%endif

%if %{with_vbox}
%files daemon-vbox
%endif

%if %{with_sanlock}
%files lock-sanlock
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/libvirt/libxl-sanlock.conf
    %endif
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/sanlock.so
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0770, root, sanlock) %{_localstatedir}/lib/libvirt/sanlock
%{_sbindir}/virt-sanlock-cleanup
%{_mandir}/man8/virt-sanlock-cleanup.8*
%attr(0755, root, root) %{_libexecdir}/libvirt_sanlock_helper
%endif

%files client
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate

%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%if %{with_qemu}
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%endif

%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virsh
%endif


%{_unitdir}/libvirt-guests.service
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%attr(0755, root, root) %{_libexecdir}/libvirt-guests.sh

%files libs -f %{name}.lang
%doc COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config(noreplace) %{_sysconfdir}/libvirt/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/cputypes.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/domaincaps.rng
%{_datadir}/libvirt/schemas/domaincheckpoint.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/networkport.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/nwfilter_params.rng
%{_datadir}/libvirt/schemas/nwfilterbinding.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storagecommon.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagepoolcaps.rng
%{_datadir}/libvirt/schemas/storagevol.rng

%{_datadir}/libvirt/cpu_map/*.xml

%{_datadir}/libvirt/test-screenshot.png

%files admin
%{_mandir}/man1/virt-admin.1*
%{_bindir}/virt-admin
%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virt-admin
%endif

%if %{with_bash_completion}
%files bash-completion
%{_datadir}/bash-completion/completions/vsh
%endif

%if %{with_wireshark}
%files wireshark
%{wireshark_plugindir}/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%if %{with_lxc}
%files login-shell
%attr(4750, root, virtlogin) %{_bindir}/virt-login-shell
%{_libexecdir}/virt-login-shell-helper
%config(noreplace) %{_sysconfdir}/libvirt/virt-login-shell.conf
%{_mandir}/man1/virt-login-shell.1*
%endif

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/virterror.h
%{_includedir}/libvirt/libvirt.h
%{_includedir}/libvirt/libvirt-admin.h
%{_includedir}/libvirt/libvirt-common.h
%{_includedir}/libvirt/libvirt-domain.h
%{_includedir}/libvirt/libvirt-domain-checkpoint.h
%{_includedir}/libvirt/libvirt-domain-snapshot.h
%{_includedir}/libvirt/libvirt-event.h
%{_includedir}/libvirt/libvirt-host.h
%{_includedir}/libvirt/libvirt-interface.h
%{_includedir}/libvirt/libvirt-network.h
%{_includedir}/libvirt/libvirt-nodedev.h
%{_includedir}/libvirt/libvirt-nwfilter.h
%{_includedir}/libvirt/libvirt-secret.h
%{_includedir}/libvirt/libvirt-storage.h
%{_includedir}/libvirt/libvirt-stream.h
%{_includedir}/libvirt/libvirt-qemu.h
%{_includedir}/libvirt/libvirt-lxc.h
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc

%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml


%changelog
* Fri Apr 28 2023 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-40.el7
- build: change dependency to allow post install erasing of /usr/bin/nc (Wim ten Have)  [Orabug: 35289777] 
- util: Make virFileClose() quiet on success (Andrea Bolognani)  [Orabug: 35090886] 

* Fri Feb 10 2023 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-39.el7
- exadata: update maxvcpus for vNUMA only (Shaleen Bathla)  [Orabug: 34863357]

* Thu Dec 01 2022 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-38.el7
- qemu: Don't report spurious errors from vCPU tid validation on hotunplug timeout (Shaleen Bathla)  [Orabug: 34826758] 
- security: fix SELinux label generation logic (Daniel P. Berrangé)  [Orabug: 34773029]  {CVE-2021-3631}
- spec: Require iproute-tc dependency for OL7 also (Shaleen Bathla)  [Orabug: 34724925] 
- qemu: Set default qdisc before setting bandwidth (Michal Prívozník)  [Orabug: 34724925] 
- qemu: Taint cpu host-passthrough only after migration (Cole Robinson)  [Orabug: 34724925]

* Tue Oct 18 2022 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-37.el7
- vNUMA: Auto adjust 'maxvcpus' for vCORE placement (Wim ten Have)  [Orabug: 34670399] 
- qemu: support kvm-poll-control performance hint (Wim ten Have)  [Orabug: 34695476] 
- qemu: fix EFI nvram removal on domain undefine (Pavel Mores)  [Orabug: 34543837] 
- util: keep the pidfile locked (Marc-André Lureau)  [Orabug: 34500172] 
- qemuProcessStartManagedPRDaemon: Don't pass -f pidfile to the daemon (Michal Prívozník)  [Orabug: 34500172] 
- virCommand: Actually acquire pidfile instead of just writing it (Michal Prívozník)  [Orabug: 34500172] 
- qemu: Don't explicitly remove pidfile after virPidFileForceCleanupPath() (Michal Prívozník)  [Orabug: 34500172] 
- virPipeImpl: Don't overwrite error (Peter Krempa)  [Orabug: 34500172] 
- src: introduce a wrapper for the pipe2() system call (Daniel P. Berrangé)  [Orabug: 34500172]

* Fri Aug 19 2022 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-36.el7
- conf: virNetDevSupportsBandwidth: move into the C file (Wim ten Have)  [Orabug: 34510458] 
- util: Netdev fixes for phys_port_id to get the ifname of a VF (Wim ten Have)  [Orabug: 34417160] 
- qemuProcessStop: Don't try to remove QoS on already removed TAP (Michal Prívozník)  [Orabug: 34206752] 
- virnetdevopenvswitch: Fix 'burst' value passed to ovs-vsctl (Michal Prívozník)  [Orabug: 34206752] 
- util: Avoid null pointer dereference when setting QoS on OVS (Jiri Denemark)  [Orabug: 34206752] 
- virnetdevopenvswitch: unify calculation of ovs and tc (zhangjl02)  [Orabug: 34206752] 
- virnetdevopenvswitch: Fix qos cleaning residual on multi interfaces (Jinsheng Zhang)  [Orabug: 34206752] 
- virnetdevopenvswitch: Introduce virNetDevOpenvswitchInterfaceClearTxQos and virNetDevOpenvswitchInterfaceClearRxQos (Jinsheng Zhang)  [Orabug: 34206752] 
- virnetdevopenvswitch: Extract common code block to a single function (Jinsheng Zhang)  [Orabug: 34206752] 
- virnetdevopenvswitch: Extract conversion parameters between virNetDevBandwidth and ovs (Jinsheng Zhang)  [Orabug: 34206752] 
- virnetdevopenvswitch: Add vmuuid notes on virNetDevOpenvswitchInterfaceSetQos (Jinsheng Zhang)  [Orabug: 34206752] 
- qemu: interface: check and use ovs command to set qos of ovs managed port (zhangjl02)  [Orabug: 34206752] 
- qemu: interface: remove setting noqueue for ovs port (zhangjl02)  [Orabug: 34206752] 
- virDomain: interface: add virNetDevOpenvswitchInterfaceSetQos and virNetDevOpenvswitchInterfaceClearQos (zhangjl02)  [Orabug: 34206752] 
- virDomain: interface: add virDomainNetDefIsOvsport (zhangjl02)  [Orabug: 34206752] 
- openvswitch: don't delete existing OVS port prior to recreating same port (Laine Stump)  [Orabug: 34206752] 
- virnetdev: move virNetDevSetRootQDisc to virnetdevbandwidth (Pavel Hrdina)  [Orabug: 34206752] 
- virnetdevbandwidth: Don't generate burst outside of boundaries (Michal Prívozník)  [Orabug: 34206752] 
- qemu_hotplug: Don't dereference NULL pointer @newb in qemuDomainChangeNet() (Michal Prívozník)  [Orabug: 34206752] 
- qemu: Restore default root qdisc when QoS is cleared out (Michal Prívozník)  [Orabug: 34206752] 
- virnetdevopenvswitch: Simplify OVS_VSCTL cmd creation (Michal Prívozník)  [Orabug: 34206752] 
- qemu: Set noqueue qdisc for TAP devices (Michal Prívozník)  [Orabug: 34206752] 
- virnetdev: Introduce virNetDevSetRootQDisc() (Michal Prívozník)  [Orabug: 34206752] 
- syntax-check: Don't forbid curly braces around single line condition body (Peter Krempa)  [Orabug: 34206752] 
- src: util: rename some program macros (Pavel Hrdina)  [Orabug: 34206752] 
- conf: rename virNetDevSupportBandwidth to virNetDevSupportsBandwidth (Ján Tomko)  [Orabug: 34206752] 
- qemu: do not revert to NULL bandwidth (Ján Tomko)  [Orabug: 34206752] 
- conf: return a const from virDomainNetGetActualVirtPortProfile (Laine Stump)  [Orabug: 34206752] 
- qemu: move runtime netdev validation into a separate function (Laine Stump)  [Orabug: 34206752] 
- conf: make arg to virDomainNetGetActualVirtPortProfile() a const (Laine Stump)  [Orabug: 34206752]

* Tue Jul 12 2022 Karl Heubaum <karl.heubaum@oracle.com> - 5.7.0-35.el7
- util: add virNetDevGetPhysPortName (Moshe Levi)  [Orabug: 34329649] 
- util: Add phys_port_name support on virPCIGetNetName (Dmytro Linkin)  [Orabug: 34329649]

* Tue Jun 28 2022 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-34.el7
- qemu: blockcopy: Allow late opening of the backing chain of a shallow copy (Peter Krempa)  [Orabug: 33091019] 
- qemu: capabilities: Introduce QEMU_CAPS_BLOCKDEV_SNAPSHOT_ALLOW_WRITE_ONLY (Peter Krempa)  [Orabug: 33091019] 
- qemuDomainBlockCopyCommon: Record updated flags to block job (Peter Krempa)  [Orabug: 33091019] 
- qemuDomainBlockPivot: Move check prior to executing the pivot steps (Peter Krempa)  [Orabug: 33091019] 
- qemuDomainBlockPivot: Copy bitmaps backing checkpoints for virDomainBlockCopy (Peter Krempa)  [Orabug: 33091019] 
- qemu: block: Introduce function to calculate bitmap handling for block-copy (Peter Krempa)  [Orabug: 33091019] 
- qemu: block: Add validator for bitmap chains accross backing chains (Peter Krempa)  [Orabug: 33091019] 
- qemu: blockjob: Store 'flags' for all the block job types (Peter Krempa)  [Orabug: 33091019] 
- qemu: blockjob: Store 'jobflags' with block job data (Peter Krempa)  [Orabug: 33091019] 
- util: json: Introduce virJSONValueArrayConcat (Peter Krempa)  [Orabug: 33091019] 
- qemu: block: Extract calls of qemuBlockGetNamedNodeData into a helper function (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Track and relabel images for bitmap merging (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Introduce support for deleting checkpoints accross snapshots (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Extract calculation of bitmap merging for checkpoint deletion (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Introduce helper to find checkpoint disk definition in parents (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: tolerate missing disks on checkpoint deletion (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Use disk definition directly when creating checkpoint (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: rename disk->chkdisk in qemuCheckpointAddActions (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: rename disk->chkdisk in qemuCheckpointDiscardBitmaps (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: split out checkpoint deletion bitmaps (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Store whether deleted checkpoint is current in a variable (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Extract and export rollback of checkpoint metadata storing (Peter Krempa)  [Orabug: 33091019] 
- qemu: block: Introduce qemuBlockNamedNodeDataGetBitmapByName (Peter Krempa)  [Orabug: 33091019] 
- qemu: snapshot: Propagate active bitmaps through external snapshots (Peter Krempa)  [Orabug: 33091019] 
- qemu: monitor: Add 'granularity' parameter for block-dirty-bitmap-add (Peter Krempa)  [Orabug: 33091019] 
- qemu: snapshot: Fold formatting of snapshot transaction into prepare func (Peter Krempa)  [Orabug: 33091019] 
- qemu: Check for explicit failure of qemuBlockSnapshotAddBlockdev (Peter Krempa)  [Orabug: 33091019] 
- qemu: monitor: Extract internals of qemuMonitorJSONBlockGetNamedNodeData (Peter Krempa)  [Orabug: 33091019] 
- qemu: monitor: Extract data about dirty-bimaps in qemuMonitorBlockGetNamedNodeData (Peter Krempa)  [Orabug: 33091019] 
- qemu: block: enable the snapshot image deletion feature (Pavel Mores)  [Orabug: 33091019] 
- qemu: block: propagate the delete flag to where it can actually be used (Pavel Mores)  [Orabug: 33091019] 
- qemu: checkpoint: fix NULL dereference at create time (Cole Robinson)  [Orabug: 33091019] 
- qemu: snapshot: Mark file becoming backingStore as read-only (Peter Krempa)  [Orabug: 33091019] 
- util: consolidate on one free callback for hash data (Daniel P. Berrangé)  [Orabug: 33091019] 
- conf: stop using hash key when free'ing hash entries (Daniel P. Berrangé)  [Orabug: 33091019] 
- qemu: checkpoint: Use qemuMonitorTransactionBitmapMergeSourceAddBitmap (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Fix rollback and access to unlocked 'vm' when deleting checkpoints (Peter Krempa)  [Orabug: 33091019] 
- qemu: snapshot: split out preparation of a snapshot with blockdev (Peter Krempa)  [Orabug: 33091019] 
- qemu: monitor: Add helper for generating data for block bitmap merging (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Extract finalizing steps of checkpoint creation (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Split out checkpoint creation code (Peter Krempa)  [Orabug: 33091019] 
- qemu: block: Don't query monitor in qemuBlockStorageSourceCreateDetectSize (Peter Krempa)  [Orabug: 33091019] 
- qemu: monitor: Introduce new interface to query-named-block-nodes (Peter Krempa)  [Orabug: 33091019] 
- util: hash: Introduce virHashHasEntry (Peter Krempa)  [Orabug: 33091019] 
- util: hash: Add new constructor 'virHashNew' (Peter Krempa)  [Orabug: 33091019] 
- util: hash: Add possibility to use simpler data free function in virHash (Peter Krempa)  [Orabug: 33091019] 
- conf: Introduce virDomainDiskByTarget (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Don't update current checkpoint until we are done (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Replace open-coded transaction action generators (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Refactor cleanup in qemuCheckpointCreateXML (Peter Krempa)  [Orabug: 33091019] 
- qemu: domain: Move checkpoint related code to qemu_checkpoint.c (Peter Krempa)  [Orabug: 33091019] 
- qemu: driver: Move checkpoint-related code to qemu_checkpoint.c (Peter Krempa)  [Orabug: 33091019] 
- qemu: Move, rename and export qemuDomObjFromDomain (Peter Krempa)  [Orabug: 33091019] 
- qemu: checkpoint: Don't forbid checkpoint when VM is marked for autodestroy (Peter Krempa)  [Orabug: 33091019] 
- Prepare to hotplug vNUMA targets for non-X86_64 guests (Wim ten Have)  [Orabug: 34256070] 
- qemu: Add missing lock in qemuProcessHandleMonitorEOF (Peng Liang)  [Orabug: 34210159]  {CVE-2021-3975}
- libvirt: Fix Auto host partitioning threads under single-socket hosts (Wim ten Have)  [Orabug: 34153152]

* Tue May 03 2022 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-33.el7
- qemu: refresh vNUMA/SMT pinning. (Wim ten Have)  [Orabug: 34083505] 
- qemu driver: Check exadataConfig and packCPUs whenever vNUMA/SMT applies (Wim ten Have)  [Orabug: 34023508] 
- nwfilter: fix crash when counting number of network filters (Daniel P. Berrangé)  [Orabug: 33973639]  {CVE-2022-0897}

* Fri Jan 28 2022 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-32.el7
- qemu: Validate config->exadata before reaping guests (Wim ten Have)  [Orabug: 33763967] 
- qemu: Make vNUMA/SMT pCPU packing L3-cache aware on AMD/E4 (Wim ten Have)  [Orabug: 33268059] 
- qemu: work exadataConfig flags directly from the QEMUdriver structure (Wim ten Have)  [Orabug: 33268059] 
- qemu: Label restore path outside of secdriver transactions (Michal Prívozník)  [Orabug: 33351242] 
- security: Introduce virSecurityManagerDomainSetPathLabelRO (Michal Prívozník)  [Orabug: 33351242]

* Fri Oct 08 2021 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-31.el7
- qemu: Do not latch guestCPUs when guests hotplug with active domain groups
  (Wim ten Have)  [Orabug: 33440015]

* Fri Oct 01 2021 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-30.el7
- qemuDomainSnapshotDiskPrepareOne: Fix logic of relative backing store update (Peter Krempa)  [Orabug: 33086913] 
- qemu: Don't set NVRAM label when creating it (Michal Prívozník)  [Orabug: 33319048] 
- qemu: protect guestCPUs from drift under vcpu guest timeouts (Wim ten Have)  [Orabug: 33368490]

* Fri Sep 03 2021 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-29.el7
- qemu: vCORE distribution under vNUMA host partitioning should balance guests vCPU:pCPU pinning (Wim ten Have)  [Orabug: 32355455] 
- qemuDomainSnapshotDiskPrepareOne: Don't load the relative path with blockdev (Peter Krempa)  [Orabug: 33151464] 
- qemu: block: Support VIR_DOMAIN_BLOCK_COMMIT/PULL/REBASE_RELATIVE with blockdev (Peter Krempa)  [Orabug: 33151464] 
- qemu: Tell secdrivers which images are top parent (Michal Prívozník)  [Orabug: 33086913] 
- security: Introduce VIR_SECURITY_DOMAIN_IMAGE_PARENT_CHAIN_TOP flag (Michal Prívozník)  [Orabug: 33086913]

* Fri Apr 30 2021 Joe Jin <joe.jin@oracle.com> - 5.7.0-28.el7
- qemu_capabilities: Rework domain caps cache (Michal Prívozník)  [Orabug: 32664432] 
- tests: fix virArchFromHost() redefine error (Joe Jin)  [Orabug: 32664432] 
- qemu: cache host arch separately from virCapsPtr (Daniel P. Berrangé)  [Orabug: 32664432] 
- cpu.c: Check properly for virCapabilitiesGetNodeInfo() retval (Michal Prívozník)  [Orabug: 32664432] 
- virStorageSourceParseBackingJSONRaw: Parse 'offset' and 'size' attributes (Peter Krempa)  [Orabug: 32164351] 
- tests: qemu: Add test data for the new <slice> element (Peter Krempa)  [Orabug: 32164351] 
- qemu: Add support for slices of type 'storage' (Peter Krempa)  [Orabug: 32164351] 
- tests: qemublock: Add cases for creating image overlays on top of disks with <slice> (Peter Krempa)  [Orabug: 32164351] 
- qemu: block: Properly format storage slice into backing store strings (Peter Krempa)  [Orabug: 32164351] 
- qemu: domain: Store nodenames of slice in status XML (Peter Krempa)  [Orabug: 32164351] 
- conf: Implement support for <slices> of disk source (Peter Krempa)  [Orabug: 32164351] 
- docs: Document the new <slices> sub-element of disk's <source> (Peter Krempa)  [Orabug: 32164351] 
- qemu: block: forbid creation of storage sources with <slice> (Peter Krempa)  [Orabug: 32164351] 
- qemuDomainValidateStorageSource: Reject unsupported slices (Peter Krempa)  [Orabug: 32164351] 
- qemuBlockStorageSourceGetFormatRawProps: format 'offset' and 'size' for slice (Peter Krempa)  [Orabug: 32164351] 
- util: virstoragefile: Add data structure for storing storage source slices (Peter Krempa)  [Orabug: 32164351] 
- tests: virstorage: Add test data for json specified raw image with offset/size (Peter Krempa)  [Orabug: 32164351] 
- docs: formatdomain: Close <source> on one of disk examples (Peter Krempa)  [Orabug: 32164351] 
- qemu: domain: Refactor formatting of node names into status XML (Peter Krempa)  [Orabug: 32164351] 
- tests: virstorage: Add test cases for "json:" pseudo-URI without 'file' wrapper (Peter Krempa)  [Orabug: 32164351] 
- virStorageSourceParseBackingJSON: Prevent arbitrary nesting with format drivers (Peter Krempa)  [Orabug: 32164351] 
- virStorageSourceParseBackingJSON: Allow 'json:' pseudo URIs without 'file' wrapper (Peter Krempa)  [Orabug: 32164351] 
- virStorageSourceJSONDriverParser: annotate 'format' drivers (Peter Krempa)  [Orabug: 32164351] 
- virStorageSourceParseBackingJSON: Move deflattening of json: URIs out of recursion (Peter Krempa)  [Orabug: 32164351] 
- virStorageSourceParseBackingJSON: Pass around original backing file string (Peter Krempa)  [Orabug: 32164351] 
- qemu: enable blockdev support (Peter Krempa)  [Orabug: 32164351] 
- qemu: Instantiate pflash via -machine when using blockdev (Peter Krempa)  [Orabug: 32164351] 
- qemu: command: Build the 'pflash' drives via -machine (Peter Krempa)  [Orabug: 32164351] 
- qemu: command: Build -blockdev-s for backing of pflash (Peter Krempa)  [Orabug: 32164351] 
- qemu: domain: Introduce helper to convert <loader> into virStorageSource (Peter Krempa)  [Orabug: 32164351] 
- qemu: domain: Store virStorageSources representing pflash backing (Peter Krempa)  [Orabug: 32164351] 
- qemu: command: Extract formatting of -drive for pflash (Peter Krempa)  [Orabug: 32164351] 
- qemu: capabilities: Add detection of the 'savevm' fix for -blockdev (Peter Krempa)  [Orabug: 32164351] 
- qemu: qapi: Add support for command features (Peter Krempa)  [Orabug: 32164351] 
- qemu: caps: Add capability for dynamic 'auto-read-only' support for files (Peter Krempa)  [Orabug: 32164351] 
- tests: qemucapabilities: Refresh data for unreleased qemu-4.2 on x86_64 (Peter Krempa)  [Orabug: 32164351] 
- qemu: caps: Base support of 'backingStoreInput' domain feature on QEMU_CAPS_BLOCKDEV (Peter Krempa)  [Orabug: 32164351] 
- docs: Document support for obeying <backingStore> of <disk> on input (Peter Krempa)  [Orabug: 32164351] 
- conf: domcaps: Add 'backingStoreInput' domain capability (Peter Krempa)  [Orabug: 32164351] 
- qemu: domcaps: Simplify adding new domaincaps based on qemu caps (Peter Krempa)  [Orabug: 32164351] 
- domaincaps: Store domain capability features in an array (Peter Krempa)  [Orabug: 32164351] 
- qemu: domcaps: Initialize all features (Peter Krempa)  [Orabug: 32164351] 
- domcaps: Add function for initializing domain caps as unsupported (Peter Krempa)  [Orabug: 32164351] 
- conf: domaincaps: Use virXMLFormatElement in virDomainCapsFormatFeatures (Peter Krempa)  [Orabug: 32164351] 
- conf: domaincaps: Extract formatting of the <features> subelement (Peter Krempa)  [Orabug: 32164351] 
- conf: domaincaps: Replace FORMAT_SINGLE macro by a function (Peter Krempa)  [Orabug: 32164351] 
- conf: capabilities: Modernize virCapabilitiesFormatMemoryBandwidth (Peter Krempa)  [Orabug: 32164351] 
- conf: caps: Modernize virCapabilitiesFormatCaches (Peter Krempa)  [Orabug: 32164351] 
- conf: turn virDomainMemtuneFormat void (Peter Krempa)  [Orabug: 32164351] 
- conf: domain: Split up formatting of <memtune> and <memoryBacking> (Peter Krempa)  [Orabug: 32164351] 
- conf: Rename virDomainCapsFeature to virDomainProcessCapsFeature (Peter Krempa)  [Orabug: 32164351] 
- conf: storagecaps: Fix broken attempt at being const-correct (Peter Krempa)  [Orabug: 32164351] 
- conf: domaincaps: Fix broken attempt at being const-correct (Peter Krempa)  [Orabug: 32164351] 
- qemu: caps: Make capability filler functions void (Peter Krempa)  [Orabug: 32164351] 
- util: buffer: Add init macro for automatically setting child XML indent (Peter Krempa)  [Orabug: 32164351] 
- qemu: snapshot: Fix inactive external snapshots when backing chain is present (Peter Krempa)  [Orabug: 32164351] 
- qemu: blockjob: Transfer 'readonly' state of images after active layer block commit (Peter Krempa)  [Orabug: 32164351] 
- qemu: command: Use XML based disk bus convertor in error message (Peter Krempa)  [Orabug: 32164351] 
- storagefile: Fill in meta->externalDataStore (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Add externalDataStore member (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Split out virStorageSourceNewFromChild (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Don't access backingStoreRaw directly in FromBackingRelative (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Fill in meta->externalDataStoreRaw (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Add externalDataStoreRaw member (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Fix backing format \0 check (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Rename qcow2GetExtensions 'format' argument (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Rename qcow2GetBackingStoreFormat (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Push extension_end calc to qcow2GetBackingStoreFormat (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Push 'start' into qcow2GetBackingStoreFormat (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Use qcowXGetBackingStore directly (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Drop now unused isQCow2 argument (Cole Robinson)  [Orabug: 32164351] 
- storagefile: Check version to determine if qcow2 or not (Cole Robinson)  [Orabug: 32164351] 
- storagefile: qcow1: Let qcowXGetBackingStore fill in format (Cole Robinson)  [Orabug: 32164351] 
- storagefile: qcow1: Fix check for empty backing file (Cole Robinson)  [Orabug: 32164351] 
- storagefile: qcow1: Check for BACKING_STORE_OK (Cole Robinson)  [Orabug: 32164351] 
- qemu: snapshot: Don't update current snapshot until we're done (Peter Krempa)  [Orabug: 32164351] 
- qemu: block: Replace snapshot transaction action generator (Peter Krempa)  [Orabug: 32164351] 
- tests: qemumonitor: Add testing for the 'transaction' command and generators (Peter Krempa)  [Orabug: 32164351] 
- qemu: monitor: Add transaction generators for snapshot APIs (Peter Krempa)  [Orabug: 32164351] 
- qemu: monitor: Add transaction generators for dirty bitmap APIs (Peter Krempa)  [Orabug: 32164351] 
- tests: qemucapabilities: fix 4.2.0 qemucapabilities (Joe Jin)  [Orabug: 32164351] 
- qemu: checkpoint: Do ACL check prior to snapshot interlocking (Peter Krempa)  [Orabug: 32164351] 
- qemu: driver: Remove misplaced qemuDomainObjEndJob in qemuDomainCheckpointGetXMLDesc (Peter Krempa)  [Orabug: 32164351] 
- conf: Drop pointless 'domain' argument from virDomainSnapshotRedefinePrep (Peter Krempa)  [Orabug: 32164351] 
- conf: Drop pointless 'domain' argument from virDomainCheckpointRedefinePrep (Peter Krempa)  [Orabug: 32164351] 
- tests: qemucapabilities: Update caps of qemu-4.1 to released version (Peter Krempa)  [Orabug: 32164351] 
- tests: add qemu capabilities data for qemu 4.2 (Peter Krempa)  [Orabug: 32164351] 
- lxc: fix compile error (Joe Jin)  [Orabug: 32164351] 
- qemu: driver: Remove QEMU_ADD_BLOCK_PARAM_LL macro (Peter Krempa)  [Orabug: 32164351] 
- qemu: driver: Don't return anything from qemuDomainBlockStatsGatherTotals (Peter Krempa)  [Orabug: 32164351] 
- qemu: driver: Remove pointless macro QEMU_BLOCK_STAT_TOTAL (Peter Krempa)  [Orabug: 32164351] 
- qemu: monitor: Change fields in qemuBlockStats to 'unsigned' (Peter Krempa)  [Orabug: 32164351] 
- qemu: monitor: Refactor cleanup in qemuMonitorJSONGetAllBlockStatsInfo (Peter Krempa)  [Orabug: 32164351] 
- qemu: monitor: Refactor cleanup in qemuMonitorJSONGetOneBlockStatsInfo (Peter Krempa)  [Orabug: 32164351] 
- qemu: monitor: Refactor cleanup in qemuMonitorJSONBlockStatsCollectData (Peter Krempa)  [Orabug: 32164351] 
- qemu: Remove stale comment for qemuDomainBlockStats (Peter Krempa)  [Orabug: 32164351] 
- qemu_blockjob: Remove secdriver metadata for whole backing chain on job completion (Michal Prívozník)  [Orabug: 32164351] 
- qemu: hotplug: Use VIR_AUTOFREE() instead VIR_FREE for strings (Daniel Henrique Barboza)  [Orabug: 32164351] 
- qemu: snapshot: Do ACL check prior to checkpoint interlocking (Peter Krempa)  [Orabug: 32164351] 
- qemuCheckDiskConfigAgainstDomain: Validate disk's SCSI address iff disk is SCSI (Xu Yandong)  [Orabug: 32164351] 
- qemuSharedDeviceEntryRemove: Free domain name before VIR_DELETE_ELEMENT (Xu Yandong)  [Orabug: 32164351] 
- qemu_capabilities: Temporarily disable dbus-vmstate capability (Michal Prívozník)  [Orabug: 32164351] 
- Revert "qemu: add socket datagram capability" (Michal Prívozník)  [Orabug: 32164351] 
- tests: qemustatusxml2xml: Fix disk target mess (Peter Krempa)  [Orabug: 32164351] 
- snapshot: Store both config and live XML in the snapshot domain (Maxiwell S. Garcia)  [Orabug: 32164351] 
- qemu: formatting XML from domain def choosing the root name (Maxiwell S. Garcia)  [Orabug: 32164351] 
- qemu: Don't leak domain def when RevertToSnapshot fails (Jiri Denemark)  [Orabug: 32164351] 
- qemu: Fix regression in snapshot-revert (Eric Blake)  [Orabug: 32164351] 
- lib: Define and use autofree for virConfPtr (Michal Prívozník)  [Orabug: 32164351] 
- qemu_conf: Use more of VIR_AUTOUNREF() (Michal Prívozník)  [Orabug: 32164351] 
- qemu_conf: Use more of VIR_AUTOFREE() (Michal Prívozník)  [Orabug: 32164351] 
- qemu_conf: Drop a pair of needless 'cleanup' labels (Michal Prívozník)  [Orabug: 32164351] 
- virhostdev: Don't unref @pcidevs twice (Michal Prívozník)  [Orabug: 32164351] 
- qemu_conf.c: introduce qemuAddRemoveSharedDeviceInternal (Daniel Henrique Barboza)  [Orabug: 32164351] 
- qemu_conf.c: introduce qemuAddRemoveSharedDiskInternal (Daniel Henrique Barboza)  [Orabug: 32164351] 
- qemu_conf.c: introduce qemuAddRemoveSharedHostdevInternal (Daniel Henrique Barboza)  [Orabug: 32164351] 
- remote: fix UNIX socket path being incorrectly built for libvirtd (eater)  [Orabug: 32164351] 
- lib: Grab write lock when modifying list of domains (Michal Prívozník)  [Orabug: 32164351] 
- qemu: reset VM id after external devices stop (Marc-André Lureau)  [Orabug: 32164351] 
- qemu: add dbus-vmstate capability (Marc-André Lureau)  [Orabug: 32164351] 
- tests: fix xml2xml tpm-emulator.xml test (Marc-André Lureau)  [Orabug: 32164351] 
- qemu: migration: Switch to blockdev mode for non-shared storage migration (Peter Krempa)  [Orabug: 32164351] 
- qemu: migration: Refactor cleanup in qemuMigrationSrcNBDStorageCopy (Peter Krempa)  [Orabug: 32164351] 
- qemu: migration: Refactor cleanup in qemuMigrationSrcNBDStorageCopyBlockdev (Peter Krempa)  [Orabug: 32164351] 
- qemu: Defer support checks for external active snapshots to blockdev code or qemu (Peter Krempa)  [Orabug: 32164351] 
- qemu: Add -blockdev support for external snapshots (Peter Krempa)  [Orabug: 32164351] 
- qemu: snapshot: Skip overlay file creation/interogation if unsupported (Peter Krempa)  [Orabug: 32164351] 
- qemu: Merge use of 'reuse' flag in qemuDomainSnapshotDiskPrepareOne (Peter Krempa)  [Orabug: 32164351] 
- qemu: Disband qemuDomainSnapshotCreateSingleDiskActive (Peter Krempa)  [Orabug: 32164351] 
- qemu: snapshot: Rename external disk snapshot handling functions (Peter Krempa)  [Orabug: 32164351] 
- qemu: snapshot: Move error preservation to qemuDomainSnapshotDiskDataCleanup (Peter Krempa)  [Orabug: 32164351] 
- qemu: snapshot: Save status and config XMLs only on success (Peter Krempa)  [Orabug: 32164351] 
- qemu: snapshot: Fix image lock handling when taking a snapshot (Peter Krempa)  [Orabug: 32164351] 
- qemu: driver: Fix shallow non-reuse block copy (Peter Krempa)  [Orabug: 32164351] 
- qemu: Explicitly pass backing store to qemuBuildStorageSourceChainAttachPrepareBlockdevTop (Peter Krempa)  [Orabug: 32164351] 
- qemu: block: explicitly pass backing store to qemuBlockStorageSourceAttachPrepareBlockdev (Peter Krempa)  [Orabug: 32164351] 
- qemu: command: Refactor qemuBuildStorageSourceChainAttachPrepareBlockdevInternal (Peter Krempa)  [Orabug: 32164351] 
- qemu: block: Explicitly specify backingStore when creating format layer props (Peter Krempa)  [Orabug: 32164351] 
- qemu: block: Unify conditions to format backing store of format node definition (Peter Krempa)  [Orabug: 32164351] 
- qemu: Prevent storage causing too much nested XML (Peter Krempa)  [Orabug: 32164351] 
- qemu: domain: Refactor cleanup in qemuDomainDetermineDiskChain (Peter Krempa)  [Orabug: 32164351] 
- qemu: hotplug: Setup disk throttling with blockdev (Peter Krempa)  [Orabug: 32164351] 
- qemu: hotplug: Use VIR_AUTOFREE in qemuDomainAttachDiskGeneric (Peter Krempa)  [Orabug: 32164351] 
- qemu: hotplug: Simplify cleanup in qemuDomainChangeMediaLegacy (Peter Krempa)  [Orabug: 32164351] 
- qemu: Fix qemuDomainObjTaint with virtlogd (Jiri Denemark)  [Orabug: 32164351] 
- qemu: monitor: Fix formatting of 'offset' in qemuMonitorJSONSaveMemory (Peter Krempa)  [Orabug: 32164351] 
- tests: qemublock: Use bigger numbers as dummy capacity/physical (Peter Krempa)  [Orabug: 32164351] 
- qemu: block: Use correct type when creating image size JSON entries (Peter Krempa)  [Orabug: 32164351] 
- Exadata: protect vNUMA/SMT from artificially injected faults (Wim ten Have)  [Orabug: 32708041] 
- virnetserver: fix some memory leaks in virNetTLSContextReloadForServer (Jin Yan)  
- virt-admin: Introduce command srv-update-tls (Zhang Bo)  [Orabug: 32768102] 
- admin: Introduce virAdmServerUpdateTlsFiles (Zhang Bo)  [Orabug: 32768102] 
- tls: Add a mutex lock on 'tlsCtxt' (Zhang Bo)  [Orabug: 32768102] 
- virnetserver: Introduce virNetServerUpdateTlsFiles (Zhang Bo)  [Orabug: 32768102]

* Mon Mar 08 2021 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-27.el7
- Exadata: protect libvirt hugepage acquisition from QEMU async init (Wim ten
  Have)  [Orabug: 32561685]

* Wed Feb 24 2021 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-26.el7
- exadata: Fix autonomous hugepage acquisition barrier hang (Wim ten Have)  [Orabug: 32537538] 
- exadata: Fix CPU Packing when out of pCPUs (Wim ten Have)  [Orabug: 32527311]

* Thu Feb 18 2021 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-25.el7
- exadata: force a host CPUs reserved pCPU threshold (Wim ten Have)  [Orabug:
  32516090]

* Thu Feb 11 2021 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-24.el7
- exadata: Add configurable libvirtd mlockall support (Wim ten Have)  [Orabug: 32479237] 
- exadata: hint a configurable number of memory init threads to qemu (Wim ten Have)  [Orabug: 32460334] 
- Exadata: domain group should allow for asymmetric creation (Wim ten Have)  [Orabug: 32060622]

* Thu Jan 28 2021 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-23.el7
- util: remove unneeded cleanup labels (Wim ten Have)  [Orabug: 32399255] 
- virnuma: Don't work around numa_node_to_cpus() for non-existent nodes (Wim ten Have)  [Orabug: 32379098]

* Thu Jan 14 2021 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-22.el7
- build: add dependency to help patch tooling (Menno Lageman)  [Orabug: 32284540] 
- Exadata: fix active guest dgroup-delete requests (Wim ten Have)  [Orabug: 32095306] 
- Exadata: fix a rogue Domain Groups dgroup-undefine flaw (Wim ten Have)  [Orabug: 31945084]

* Wed Nov 04 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-21.el7
- exadata: Fix the validation when defining domain groups (Wim ten Have)  [Orabug: 32085856] 
- Revert "qemu: don't take agent and monitor job for shutdown" (Menno Lageman)  [Orabug: 32080283] 
- Revert "qemu: don't hold a monitor and agent job for reboot" (Menno Lageman)  [Orabug: 32080283] 
- Revert "qemu: don't hold monitor and agent job when setting time" (Menno Lageman)  [Orabug: 32080283] 
- Revert "qemu: remove use of qemuDomainObjBeginJobWithAgent()" (Menno Lageman)  [Orabug: 32080283] 
- qemu: improve error message when guest vcpu count exceeds domain group limit (Menno Lageman)  [Orabug: 31985111] 
- qemu: Autonomous hugepage acquisition for 2-MiB and 1-GiB guest memoryBacking. (Wim ten Have)  
- qemu: Fix a qemuMemReleaseHostHugepages state error (Wim ten Have)  [Orabug: 32069203] 
- qemu: avoid guest CPU process handling if exadataConfig is disabled (Wim ten Have)  [Orabug: 32053696] 
- domain_conf: Relax SCSI addr used check (Michal Prívozník)  [Orabug: 31386162] 
- domain_conf: Make virDomainDeviceFindSCSIController accept virDomainDeviceDriveAddress struct (Michal Prívozník)  [Orabug: 31386162]

* Fri Oct 09 2020 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-20.el7
- qemu: remove use of qemuDomainObjBeginJobWithAgent() (Jonathon Jongsma)  [Orabug: 31990187]  {CVE-2019-20485}
- qemu: don't hold monitor and agent job when setting time (Jonathon Jongsma)  [Orabug: 31990187]  {CVE-2019-20485}
- qemu: don't hold a monitor and agent job for reboot (Jonathon Jongsma)  [Orabug: 31990187]  {CVE-2019-20485}
- qemu: don't take agent and monitor job for shutdown (Jonathon Jongsma)  [Orabug: 31990187]  {CVE-2019-20485}
- qemu: agent: set ifname to NULL after freeing (Ján Tomko)  [Orabug: 31964426]  {CVE-2020-25637}
- rpc: require write acl for guest agent in virDomainInterfaceAddresses (Ján Tomko)  [Orabug: 31964426]  {CVE-2020-25637}
- rpc: add support for filtering @acls by uint params (Ján Tomko)  [Orabug: 31964426]  {CVE-2020-25637}
- rpc: gendispatch: handle empty flags (Ján Tomko)  [Orabug: 31964426]  {CVE-2020-25637}
- qemu: blockcopy: Fix conditions when virStorageSource should be initialized (Peter Krempa)  [Orabug: 31517934] 
- qemu: blockcopy: Report error on image format detection failure (Peter Krempa)  [Orabug: 31517934]

* Thu Sep 03 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-19.el7
- qemu: Verify use of hugepages when releasing its acquired status (Wim ten
  Have)  [Orabug: 31839035]

* Tue Aug 25 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-18.el7
- qemu: Autonomous hugepages acquisition and release (Wim ten Have)  [Orabug:
  31367986]

* Thu Jul 09 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-17.el7
- qemu: Fix cpu boundary checks when starting or configuring guest domains. (Wim ten Have)  [Orabug: 31469231] 
- libvirt: Allocate max possible CPUs for QEMU to prepare guest memory (Wim ten Have)  [Orabug: 31064560]

* Thu Jun 25 2020 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-16.el7
- qemu: format 'x-aw-bits' on intel-iommu command line (Menno Lageman)  
- qemu: format address wdith on intel-iommu command line (Menno Lageman)  
- conf: add address width attribute to iommu (Menno Lageman)  
- tests: add tests for host-phys-bits KVM feature (Menno Lageman)  [Orabug: 31354547] 
- qemu: support host-phys-bits KVM feature (Menno Lageman)  [Orabug: 31374547] 
- storage: Fix daemon crash on lookup storagepool by targetpath (Yi Li)  [Orabug: 31439483]  {CVE-2020-10703}

* Tue Jun 02 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-15.el7
- qemu: Escape the qemu driver systemd DOT hoax (Wim ten Have)  [Orabug:
  31380815]

* Thu May 14 2020 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-14.el7
- vmx: make 'fileName' optional for CD-ROMs (Pino Toscano)  [Orabug: 31350200] 
- vmx: shortcut earlier few 'ignore' cases in virVMXParseDisk() (Pino Toscano)  [Orabug: 31350200] 
- domain group: Fix a potential SEGV while restoring guest domains (Wim ten Have)  [Orabug: 31285615] 
- cpu_map: Distinguish Cascadelake-Server from Skylake-Server (Jiri Denemark)  [Orabug: 31214897] 
- cpu_map: Add more -noTSX x86 CPU models (Christian Ehrhardt)  [Orabug: 31214897] 
- qemuDomainGetStatsIOThread: Don't leak array with 0 iothreads (Peter Krempa)  [Orabug: 31251756]  {CVE-2020-12430}

* Wed Apr 29 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-13.el7
- domain groups: Fix multiple Domain Group vCPU administration flaws (Wim ten Have)  [Orabug: 31145304] 
- qemu: fix missing #if defined(ENABLE_EXADATA) (Menno Lageman)  
- build: Fix qemu-submodule-init syntax-check issue (Wim ten Have)  
- libvirt: Fix various introduced Fedora/RHEL build violations (Wim ten Have)  [Orabug: 31143337] 
- qemu: don't hold both jobs for suspend (Jonathon Jongsma)  [Orabug: 31073098]  {CVE-2019-20485}
- domain groups: qemu driver error refers to pCPUs instead of vCPUs (Wim ten Have)  [Orabug: 31075757] 
- node_device_conf: Don't leak @physical_function in virNodeDeviceGetPCISRIOVCaps (Jiang Kun)  [Orabug: 31070337]

* Thu Mar 19 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-12.el7
- libvirt: vNUMA automatic host paritioning allows erroneous vcpu settings (Wim ten Have)  [Orabug: 31050313] 
- remote: do not stop libvirtd after period of inactivity (Menno Lageman)  [Orabug: 31003707] 
- remote: do not use socket activation by default (Menno Lageman)  [Orabug: 31003707] 
- qemu driver: handle targetNode under memory hot-plug operations (Wim ten Have)  [Orabug: 31009716] 
- domain groups: refresh dgbase host capabilities prior to defining a new group (Wim ten Have)  [Orabug: 31026069] 
- domain groups: Always cleanup system.slice controlled hugepage reservations (Wim ten Have)  [Orabug: 31025853] 
- domain groups: Enable DGs upon fresh groups arrival (Wim ten Have)  [Orabug: 31021247] 
- domain groups: Skip undefined domain groups when validating lists (Wim ten Have)  [Orabug: 31030117]

* Tue Mar 10 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-11.el7
- domain groups: Add functionality to control NUMA node alignment (Wim ten Have)  [Orabug: 30988105] 
- domain groups: A rename should always update active and config domain definitions (Wim ten Have)  [Orabug: 30999730]

* Thu Mar 05 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-10.el7
- domain groups: refresh dgbase depending host capabilities before rendering the cpuguestmask (Wim ten Have)  [Orabug: 30987361] 
- conf: domain group validation errors should print correct group info (Menno Lageman)  [Orabug: 30988428] 
- qemu: reserve hugepages when memoryBacking when live attaching memory (Wim ten Have)  [Orabug: 30985510] 
- domain groups: avoid virDomainGroupInit if exadataConfig is disabled (Wim ten Have)  [Orabug: 30985907]

* Fri Feb 28 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-9.el7
- vNUMA: distinguish standard and vNUMA memory 'setmaxmem' operations (Wim ten
  Have)  [Orabug: 30894536]

* Thu Feb 27 2020 Wim ten Have <wim.ten.have@oracle.com> - 5.7.0-8.el7
- domain groups: End Of BETA (Wim ten Have)  
- domaingroups: ExaData Domain Groups POC (Wim ten Have)  
- domaingroup: preliminary virsh support for domain groups - drop #4 (Menno Lageman)  
- tests: add various tests to exercise vNUMA host partitioning (Wim ten Have)  [Orabug: 29720293] 
- qemu: driver changes for new vNUMA Host and Nodeset partitioning (Wim ten Have)  [Orabug: 29720293] 
- XML definitions for guest vNUMA and parsing routines (Wim ten Have)  [Orabug: 29720293] 
- Revert "exadata: can not configure shared memory hosted disk devices for vhostmd.service" (Menno Lageman)  
- qemu: Forcibly mknod() even if it exists (Michal Prívozník)

* Fri Jan 31 2020 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-5.el7
- exadata: can not configure shared memory hosted disk devices for
  vhostmd.service (Menno Lageman)  [Orabug: 30598065]

* Thu Jan 23 2020 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-4.el7
- build: skip copyright check for gnulib (Menno Lageman)  
- Revert "network: pull global chain init into separate method" (Menno Lageman)  [Orabug: 30611188] 
- Revert "network: add more debugging of firewall chain creation" (Menno Lageman)  [Orabug: 30611188] 
- Revert "network: delay global firewall setup if no networks are running" (Menno Lageman)  [Orabug: 30611188] 
- qemu-submodule-init: Add Git submodule init script (Karl Heubaum)  [Orabug: 30796221]

* Fri Nov 01 2019 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-3.el7
- Add VMware esx support (Menno Lageman)  [Orabug: 30449929]

* Thu Oct 24 2019 Menno Lageman <menno.lageman@oracle.com> - 5.7.0-2.el7
- enable VMware hypervisor driver

